@@ -51,6 +51,7 @@ ifaces_model_create (void)
 			      G_TYPE_OBJECT,
 			      G_TYPE_STRING,
 			      G_TYPE_BOOLEAN,
+			      G_TYPE_BOOLEAN,
 			      G_TYPE_BOOLEAN);
   return GTK_TREE_MODEL (store);
 }
@@ -125,6 +126,7 @@ add_list_columns (GtkTreeView  *table,
 					       "Interface",
 					       renderer,
 					       "pixbuf", COL_IMAGE,
+					       "sensitive", COL_NOT_INCONSISTENT,
 					       NULL);
 
   renderer = gtk_cell_renderer_text_new ();
@@ -237,18 +239,27 @@ static GdkPixbuf*
 get_iface_pixbuf (OobsIface *iface)
 {
   GdkPixbuf *pixbuf = NULL;
+  const gchar *icon = NULL;
 
   if (OOBS_IS_IFACE_WIRELESS (iface))
-    pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/wavelan-48.png", NULL);
+    icon = "gnome-dev-wavelan";
   else if (OOBS_IS_IFACE_IRLAN (iface))
-    pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/irda-48.png", NULL);
+    icon = "irda";
   else if (OOBS_IS_IFACE_ETHERNET (iface))
-    pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/connection-ethernet.png", NULL);
+    icon = "gnome-dev-ethernet";
   else if (OOBS_IS_IFACE_PLIP (iface))
-    pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/plip-48.png", NULL);
+    icon = "plip";
   else if (OOBS_IS_IFACE_ISDN (iface))
-    pixbuf = gdk_pixbuf_new_from_file (PIXMAPS_DIR "/ppp.png", NULL);
+    icon = "gnome-modem";
 
+  if (icon)
+    pixbuf = gtk_icon_theme_load_icon (gst_tool_get_icon_theme (tool),
+				       icon, 48, 0, NULL);
+
+  /* fallback to a "generic" icon */
+  if (!pixbuf)
+    pixbuf = gtk_icon_theme_load_icon (gst_tool_get_icon_theme (tool),
+				       "gnome-fs-network", 48, 0, NULL);
   return pixbuf;
 }
 
@@ -266,26 +277,26 @@ get_iface_secondary_text (OobsIface *iface)
     {
       if (OOBS_IS_IFACE_WIRELESS (iface))
 	g_string_append_printf (str, _("<b>Essid:</b> %s "),
-				oobs_iface_wireless_get_essid (iface));
+				oobs_iface_wireless_get_essid (OOBS_IFACE_WIRELESS (iface)));
 
-      if (oobs_iface_ethernet_get_configuration_method (iface) != OOBS_METHOD_DHCP)
+      if (oobs_iface_ethernet_get_configuration_method (OOBS_IFACE_ETHERNET (iface)) != OOBS_METHOD_DHCP)
 	g_string_append_printf (str, _("<b>Address:</b> %s <b>Subnet mask:</b> %s"),
-				oobs_iface_ethernet_get_ip_address (iface),
-				oobs_iface_ethernet_get_network_mask (iface));
+				oobs_iface_ethernet_get_ip_address (OOBS_IFACE_ETHERNET (iface)),
+				oobs_iface_ethernet_get_network_mask (OOBS_IFACE_ETHERNET (iface)));
       else
 	g_string_append_printf (str, _("<b>Address:</b> DHCP"));
     }
   else if (OOBS_IS_IFACE_PLIP (iface))
     {
       g_string_append_printf (str, _("<b>Address:</b> %s <b>Remote address:</b> %s"),
-			      oobs_iface_plip_get_address (iface),
-			      oobs_iface_plip_get_remote_address (iface));
+			      oobs_iface_plip_get_address (OOBS_IFACE_PLIP (iface)),
+			      oobs_iface_plip_get_remote_address (OOBS_IFACE_PLIP (iface)));
     }
   else if (OOBS_IS_IFACE_ISDN (iface))
     {
       g_string_append_printf (str, _("<b>Phone number:</b> %s <b>Login:</b> %s"),
-			      oobs_iface_isdn_get_phone_number (iface),
-			      oobs_iface_isdn_get_login (iface));
+			      oobs_iface_isdn_get_phone_number (OOBS_IFACE_ISDN (iface)),
+			      oobs_iface_isdn_get_login (OOBS_IFACE_ISDN (iface)));
     }
 
   text = str->str;
@@ -337,7 +348,7 @@ ifaces_model_modify_interface_at_iter (GtkTreeIter *iter)
   GtkTreeModel *model;
   OobsIface *iface;
   gchar *desc;
-  gboolean show_name;
+  gboolean show_name, configured;
   GdkPixbuf *pixbuf;
 
   model = GST_NETWORK_TOOL (tool)->interfaces_model;
@@ -348,16 +359,20 @@ ifaces_model_modify_interface_at_iter (GtkTreeIter *iter)
 		      -1);
   desc = get_iface_desc (OOBS_IFACE (iface), show_name);
   pixbuf = get_iface_pixbuf (OOBS_IFACE (iface));
+  configured = oobs_iface_get_configured (OOBS_IFACE (iface));
 
   gtk_list_store_set (GTK_LIST_STORE (model), iter,
 		      COL_ACTIVE, oobs_iface_get_active (OOBS_IFACE (iface)),
 		      COL_IMAGE, pixbuf,
 		      COL_DESC, desc,
 		      COL_DEV, oobs_iface_get_device_name (OOBS_IFACE (iface)),
-		      COL_INCONSISTENT, !oobs_iface_get_configured (OOBS_IFACE (iface)),
+		      COL_INCONSISTENT, !configured,
+		      COL_NOT_INCONSISTENT, configured,
 		      -1);
 
-  g_object_unref (pixbuf);
+  if (pixbuf)
+    g_object_unref (pixbuf);
+
   g_object_unref (iface);
   g_free (desc);
 }
